[libvirt] [PATCH] virsh: fixed trivial comment and debug message in vshCommandOptVolBy function

Justin Clift justin at salasaga.org
Tue Jun 8 14:46:06 UTC 2010


---
 tools/virsh.c |    6 ++++--
 1 files changed, 4 insertions(+), 2 deletions(-)

diff --git a/tools/virsh.c b/tools/virsh.c
index e444501..2e8cbec 100644
--- a/tools/virsh.c
+++ b/tools/virsh.c
@@ -9411,17 +9411,19 @@ vshCommandOptVolBy(vshControl *ctl, const vshCmd *cmd,
     if (name)
         *name = n;
 
     /* try it by PATH */
     if (pool && (flag & VSH_BYNAME)) {
-        vshDebug(ctl, 5, "%s: <%s> trying as vol UUID\n",
+        vshDebug(ctl, 5, "%s: <%s> trying as vol name\n",
                  cmd->def->name, optname);
         vol = virStorageVolLookupByName(pool, n);
     }
+    /* try it by key */
     if (vol == NULL && (flag & VSH_BYUUID)) {
         vshDebug(ctl, 5, "%s: <%s> trying as vol key\n",
                  cmd->def->name, optname);
         vol = virStorageVolLookupByKey(ctl->conn, n);
     }
+    /* try it by path */
     if (vol == NULL && (flag & VSH_BYUUID)) {
         vshDebug(ctl, 5, "%s: <%s> trying as vol path\n",
                  cmd->def->name, optname);
@@ -9411,17 +9411,19 @@ vshCommandOptVolBy(vshControl *ctl, const vshCmd *cmd,
         *name = n;
 
-    /* try it by PATH */
+    /* try it by name */
     if (pool && (flag & VSH_BYNAME)) {
-- 
1.7.0.1




More information about the libvir-list mailing list